diff --git a/ChangeLog b/ChangeLog
index 21c57d2bdebd6b116b236a4cb8bfda471bd0a3bd..f00e5e504fcca4c03e7d48d33eaa284031eeb9d8 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -6,7 +6,7 @@ CVS code -
 	  renumber_all(), renumber(), do_alt_speller(), and
 	  backup_lines(). (DLR)
 	- Reorder some functions for consistency. (DLR)
-	- Rename variable open_files filebuffer, for consistency. (DLR)
+	- Rename variable open_files openfile, for consistency. (DLR)
 - global.c:
   shortcut_init()
 	- Simplify wording of nano_gotoline_msg. (Jordi)
diff --git a/src/proto.h b/src/proto.h
index 406015a8d35355003bfc2e05effe45eafeb5cf59..199e97dc45a58eb88514f91899691c265f9315e7 100644
--- a/src/proto.h
+++ b/src/proto.h
@@ -101,7 +101,7 @@ extern filestruct *mark_beginbuf;
 #endif
 
 #ifdef ENABLE_MULTIBUFFER
-extern openfilestruct *filebuffer;
+extern openfilestruct *openfile;
 #endif
 
 #ifdef ENABLE_COLOR
diff --git a/src/files.c b/src/files.c
index d7eafc7fb4b9879dc0acae606fa7f635e6d67bd3..cf45bd6e52bd222ce25ace624fc81035cee53ce6 100644
--- a/src/files.c
+++ b/src/files.c
@@ -99,133 +99,132 @@ void free_openfilestruct(openfilestruct *src)
 }
 #endif
 
 /* Add/update an entry to the filebuffer openfilestruct.  If update is
  * FALSE, a new entry is created; otherwise, the current entry is
  * updated. */
 void add_open_file(bool update)
 {
-    if (update && filebuffer == NULL)
+    if (update && openfile == NULL)
 	return;
 
-    /* If there are no entries in filebuffer, make the first one. */
-    if (filebuffer == NULL) {
-	filebuffer = make_new_opennode();
-	splice_opennode(filebuffer, filebuffer, filebuffer);
+    /* If there are no entries in openfile, make the first one. */
+    if (openfile == NULL) {
+	openfile = make_new_opennode();
+	splice_opennode(openfile, openfile, openfile);
     /* Otherwise, if we're not updating, make a new entry for
      * filebuffer and splice it in after the current entry. */
     } else if (!update) {
-	splice_opennode(filebuffer, make_new_opennode(),
-		filebuffer->next);
-	filebuffer = filebuffer->next;
+	splice_opennode(openfile, make_new_opennode(), openfile->next);
+	openfile = openfile->next;
     }
 
     /* Save the current filename. */
-    filebuffer->filename = mallocstrcpy(filebuffer->filename, filename);
+    openfile->filename = mallocstrcpy(openfile->filename, filename);
 
 #ifndef NANO_SMALL
     /* Save the current file's stat. */
-    filebuffer->originalfilestat = originalfilestat;
+    openfile->originalfilestat = originalfilestat;
 #endif
 
     /* Save the current file buffer. */
-    filebuffer->fileage = fileage;
-    filebuffer->filebot = filebot;
+    openfile->fileage = fileage;
+    openfile->filebot = filebot;
 
     /* Save the current top of the edit window. */
-    filebuffer->edittop = edittop;
+    openfile->edittop = edittop;
 
     /* Save the current line. */
-    filebuffer->current = current;
+    openfile->current = current;
 
     /* Save the current cursor position. */
-    filebuffer->current_x = current_x;
+    openfile->current_x = current_x;
 
     /* Save the current place we want. */
-    filebuffer->placewewant = placewewant;
+    openfile->placewewant = placewewant;
 
     /* Save the current total number of lines. */
-    filebuffer->totlines = totlines;
+    openfile->totlines = totlines;
 
     /* Save the current total size. */
-    filebuffer->totsize = totsize;
+    openfile->totsize = totsize;
 
     /* Start with no flags saved. */
-    filebuffer->flags = 0;
+    openfile->flags = 0;
 
     /* Save the current modification status. */
     if (ISSET(MODIFIED))
-	filebuffer->flags |= MODIFIED;
+	openfile->flags |= MODIFIED;
 
 #ifndef NANO_SMALL
     /* Save the current marking status and mark, if applicable. */
     if (ISSET(MARK_ISSET)) {
-	filebuffer->flags |= MARK_ISSET;
-	filebuffer->mark_beginbuf = mark_beginbuf;
-	filebuffer->mark_beginx = mark_beginx;
+	openfile->flags |= MARK_ISSET;
+	openfile->mark_beginbuf = mark_beginbuf;
+	openfile->mark_beginx = mark_beginx;
     }
 
     /* Save the current file format. */
-    filebuffer->fmt = fmt;
+    openfile->fmt = fmt;
 #endif
 
 #ifdef DEBUG
-    fprintf(stderr, "filename is %s\n", filebuffer->filename);
+    fprintf(stderr, "filename is %s\n", openfile->filename);
 #endif
 }
 
 /* Read the current entry in the filebuffer structure and set up the
  * currently open file buffer using that entry's information. */
 void load_open_file(void)
 {
-    assert(filebuffer != NULL);
+    assert(openfile != NULL);
 
     /* Restore the current filename. */
-    filename = mallocstrcpy(filename, filebuffer->filename);
+    filename = mallocstrcpy(filename, openfile->filename);
 
 #ifndef NANO_SMALL
     /* Restore the current file's stat. */
-    originalfilestat = filebuffer->originalfilestat;
+    originalfilestat = openfile->originalfilestat;
 #endif
 
     /* Restore the current file buffer. */
-    fileage = filebuffer->fileage;
-    filebot = filebuffer->filebot;
+    fileage = openfile->fileage;
+    filebot = openfile->filebot;
 
     /* Restore the current top of the edit window. */
-    edittop = filebuffer->edittop;
+    edittop = openfile->edittop;
 
     /* Restore the current line. */
-    current = filebuffer->current;
+    current = openfile->current;
 
     /* Restore the current cursor position. */
-    current_x = filebuffer->current_x;
+    current_x = openfile->current_x;
 
     /* Restore the current place we want. */
-    placewewant = filebuffer->placewewant;
+    placewewant = openfile->placewewant;
 
     /* Restore the current total number of lines. */
-    totlines = filebuffer->totlines;
+    totlines = openfile->totlines;
 
     /* Restore the current total size. */
-    totsize = filebuffer->totsize;
+    totsize = openfile->totsize;
 
     /* Restore the current modification status. */
-    if (filebuffer->flags & MODIFIED)
+    if (openfile->flags & MODIFIED)
 	SET(MODIFIED);
     else
 	UNSET(MODIFIED);
 
 #ifndef NANO_SMALL
     /* Restore the current marking status and mark, if applicable. */
-    if (filebuffer->flags & MARK_ISSET) {
-	mark_beginbuf = filebuffer->mark_beginbuf;
-	mark_beginx = filebuffer->mark_beginx;
+    if (openfile->flags & MARK_ISSET) {
+	mark_beginbuf = openfile->mark_beginbuf;
+	mark_beginx = openfile->mark_beginx;
 	SET(MARK_ISSET);
     } else
 	UNSET(MARK_ISSET);
 
     /* Restore the current file format. */
-    fmt = filebuffer->fmt;
+    fmt = openfile->fmt;
 #endif
 
 #ifdef ENABLE_COLOR
@@ -240,23 +239,23 @@ void load_open_file(void)
 /* Open either the next or previous file buffer. */
 void open_prevnext_file(bool next_file)
 {
-    assert(filebuffer != NULL);
+    assert(openfile != NULL);
 
     add_open_file(TRUE);
 
     /* If only one file buffer is open, indicate it on the statusbar and
      * get out. */
-    if (filebuffer == filebuffer->next) {
+    if (openfile == openfile->next) {
 	statusbar(_("No more open file buffers"));
 	return;
     }
 
     /* Switch to the next or previous file, depending on the value of
      * next. */
-    filebuffer = next_file ? filebuffer->next : filebuffer->prev;
+    openfile = next_file ? openfile->next : openfile->prev;
 
 #ifdef DEBUG
-    fprintf(stderr, "filename is %s\n", filebuffer->filename);
+    fprintf(stderr, "filename is %s\n", openfile->filename);
 #endif
 
     /* Load the file we switched to. */
@@ -264,44 +263,44 @@ void open_prevnext_file(bool next_file)
 
     /* And indicate the switch on the statusbar. */
     statusbar(_("Switched to %s"),
-      ((filebuffer->filename[0] == '\0') ? _("New Buffer") :
-	filebuffer->filename));
+	((openfile->filename[0] == '\0') ? _("New Buffer") :
+	openfile->filename));
 
 #ifdef DEBUG
     dump_buffer(current);
 #endif
 }
 
 /* Open the previous entry in the filebuffer structure.  This function
  * is used by the shortcut list. */
 void open_prevfile_void(void)
 {
     open_prevnext_file(FALSE);
 }
 
 /* Open the next entry in the filebuffer structure.  This function is
  * used by the shortcut list. */
 void open_nextfile_void(void)
 {
     open_prevnext_file(TRUE);
 }
 
 /* Delete an entry from the filebuffer filestruct.  After deletion of an
  * entry, the next entry is opened.  Return TRUE on success or FALSE if
  * there are no more open file buffers. */
 bool close_open_file(void)
 {
-    assert(filebuffer != NULL);
+    assert(openfile != NULL);
 
     /* If only one file is open, get out. */
-    if (filebuffer == filebuffer->next)
+    if (openfile == openfile->next)
 	return FALSE;
 
     /* Open the next file. */
     open_nextfile_void();
 
     /* Close the file we had open before. */
-    unlink_opennode(filebuffer->prev);
+    unlink_opennode(openfile->prev);
 
     /* Reinitialize the shortcut list. */
     shortcut_init(FALSE);
@@ -388,7 +387,7 @@ void load_file(void)
     current = fileage;
 
 #ifdef ENABLE_MULTIBUFFER
     /* Add a new entry to the filebuffer structure. */
     add_open_file(FALSE);
 
     /* Reinitialize the shortcut list. */
@@ -685,7 +684,7 @@ void execute_command(const char *command)
 {
 #ifdef ENABLE_MULTIBUFFER
     if (ISSET(MULTIBUFFER)) {
 	/* Update the current entry in the filebuffer structure. */
 	add_open_file(TRUE);
 	new_file();
 	UNSET(MODIFIED);
@@ -694,7 +693,7 @@ void execute_command(const char *command)
 #endif /* ENABLE_MULTIBUFFER */
     open_pipe(command);
 #ifdef ENABLE_MULTIBUFFER
     /* Add this new entry to the filebuffer structure. */
     if (ISSET(MULTIBUFFER))
 	load_file();
 #endif /* ENABLE_MULTIBUFFER */
@@ -713,7 +712,7 @@ void load_buffer(const char *name)
 	/* new_buffer says whether we load into this buffer or a new
 	 * one.  If new_buffer is TRUE, we display "New File" if the
 	 * file is not found, and if it is found we set filename and add
 	 * a new filebuffer entry. */
     FILE *f;
     int rc;
 	/* rc == -2 means that the statusbar displayed "New File".  -1
@@ -728,7 +727,7 @@ void load_buffer(const char *name)
 #endif
 
 #ifdef ENABLE_MULTIBUFFER
     /* Update the current entry in the filebuffer structure. */
     add_open_file(TRUE);
 #endif
 
@@ -763,7 +762,7 @@ void load_buffer(const char *name)
 #endif
     }
 
     /* Add this new entry to the filebuffer structure if we have
      * multibuffer support, or to the main filestruct if we don't. */
     if (rc != -1 && new_buffer)
 	load_file();
@@ -1926,7 +1925,7 @@ int do_writeout(bool exiting)
 
 #ifdef ENABLE_MULTIBUFFER
 	    /* If we're not about to exit, update the current entry in
 	     * the filebuffer structure. */
 	    if (!exiting)
 		add_open_file(TRUE);
 #endif
@@ -99,133 +99,132 @@ void free_openfilestruct(openfilestruct *src)
 #endif
 
-/* Add/update an entry to the filebuffer openfilestruct.  If update is
+/* Add/update an entry to the openfile openfilestruct.  If update is
  * FALSE, a new entry is created; otherwise, the current entry is
  * updated. */
@@ -99,133 +99,132 @@ void free_openfilestruct(openfilestruct *src)
     /* Otherwise, if we're not updating, make a new entry for
-     * filebuffer and splice it in after the current entry. */
+     * openfile and splice it in after the current entry. */
     } else if (!update) {
@@ -99,133 +99,132 @@ void free_openfilestruct(openfilestruct *src)
 }
 
-/* Read the current entry in the filebuffer structure and set up the
+/* Read the current entry in the openfile structure and set up the
  * currently open file buffer using that entry's information. */
 void load_open_file(void)
@@ -264,44 +263,44 @@ void open_prevnext_file(bool next_file)
 }
 
-/* Open the previous entry in the filebuffer structure.  This function
+/* Open the previous entry in the openfile structure.  This function
  * is used by the shortcut list. */
 void open_prevfile_void(void)
@@ -264,44 +263,44 @@ void open_prevnext_file(bool next_file)
 }
 
-/* Open the next entry in the filebuffer structure.  This function is
+/* Open the next entry in the openfile structure.  This function is
  * used by the shortcut list. */
 void open_nextfile_void(void)
@@ -264,44 +263,44 @@ void open_prevnext_file(bool next_file)
 }
 
-/* Delete an entry from the filebuffer filestruct.  After deletion of an
+/* Delete an entry from the openfile filestruct.  After deletion of an
  * entry, the next entry is opened.  Return TRUE on success or FALSE if
  * there are no more open file buffers. */
@@ -388,7 +387,7 @@ void load_file(void)
 
 #ifdef ENABLE_MULTIBUFFER
-    /* Add a new entry to the filebuffer structure. */
+    /* Add a new entry to the openfile structure. */
     add_open_file(FALSE);
 
@@ -685,7 +684,7 @@ void execute_command(const char *command)
 #ifdef ENABLE_MULTIBUFFER
     if (ISSET(MULTIBUFFER)) {
-	/* Update the current entry in the filebuffer structure. */
+	/* Update the current entry in the openfile structure. */
 	add_open_file(TRUE);
 	new_file();
@@ -694,7 +693,7 @@ void execute_command(const char *command)
     open_pipe(command);
 #ifdef ENABLE_MULTIBUFFER
-    /* Add this new entry to the filebuffer structure. */
+    /* Add this new entry to the openfile structure. */
     if (ISSET(MULTIBUFFER))
 	load_file();
@@ -713,7 +712,7 @@ void load_buffer(const char *name)
 	 * one.  If new_buffer is TRUE, we display "New File" if the
 	 * file is not found, and if it is found we set filename and add
-	 * a new filebuffer entry. */
+	 * a new openfile entry. */
     FILE *f;
     int rc;
@@ -728,7 +727,7 @@ void load_buffer(const char *name)
 
 #ifdef ENABLE_MULTIBUFFER
-    /* Update the current entry in the filebuffer structure. */
+    /* Update the current entry in the openfile structure. */
     add_open_file(TRUE);
 #endif
@@ -763,7 +762,7 @@ void load_buffer(const char *name)
     }
 
-    /* Add this new entry to the filebuffer structure if we have
+    /* Add this new entry to the openfile structure if we have
      * multibuffer support, or to the main filestruct if we don't. */
     if (rc != -1 && new_buffer)
@@ -1926,7 +1925,7 @@ int do_writeout(bool exiting)
 #ifdef ENABLE_MULTIBUFFER
 	    /* If we're not about to exit, update the current entry in
-	     * the filebuffer structure. */
+	     * the openfile structure. */
 	    if (!exiting)
 		add_open_file(TRUE);
diff --git a/src/global.c b/src/global.c
index cf0b6cf8c3b25b0f9522e5b74370d626793429f3..23ba27406da284a6441ba5d3083edb5fcd163d50 100644
--- a/src/global.c
+++ b/src/global.c
@@ -69,8 +69,8 @@ partition *filepart = NULL;	/* A place to store a portion of the
 				   file struct */
 
 #ifdef ENABLE_MULTIBUFFER
-openfilestruct *filebuffer = NULL;	/* The list of open file
-					   buffers */
+openfilestruct *openfile = NULL;
+				/* The list of open file buffers */
 #endif
 
 #if !defined(NANO_SMALL) && defined(ENABLE_NANORC)
@@ -413,8 +413,7 @@ void shortcut_init(bool unjustify)
     /* Translators: try to keep this string under 10 characters long */
     sc_init_one(&main_list, NANO_EXIT_KEY,
 #ifdef ENABLE_MULTIBUFFER
-	filebuffer != NULL && filebuffer != filebuffer->next ?
-	N_("Close") :
+	openfile != NULL && openfile != openfile->next ? N_("Close") :
 #endif
 	exit_msg, IFHELP(nano_exit_msg, NANO_NO_KEY), NANO_EXIT_FKEY,
 	NANO_NO_KEY, VIEW, do_exit);
@@ -1243,12 +1242,12 @@ void thanks_for_all_the_fish(void)
 #endif
 #ifdef ENABLE_MULTIBUFFER
     /* Free the memory associated with each open file buffer. */
-    if (filebuffer != NULL) {
-	/* Make sure filebuffer->fileage is up to date, in case we've
+    if (openfile != NULL) {
+	/* Make sure openfile->fileage is up to date, in case we've
 	 * cut the top line of the file. */
-	filebuffer->fileage = fileage;
+	openfile->fileage = fileage;
 
-	free_openfilestruct(filebuffer);
+	free_openfilestruct(openfile);
     }
 #else
     if (fileage != NULL)
diff --git a/src/nano.c b/src/nano.c
index c0cf1202c14fa1cce16a1cea113ff9c5e12edae9..ca79bc4b991c16c45121cc74ca74602cf34cbd74 100644
--- a/src/nano.c
+++ b/src/nano.c
@@ -521,19 +521,19 @@ void die(const char *msg, ...)
 
 #ifdef ENABLE_MULTIBUFFER
     /* Save all of the other modified file buffers, if any. */
-    if (filebuffer != NULL) {
-	openfilestruct *tmp = filebuffer;
+    if (openfile != NULL) {
+	openfilestruct *tmp = openfile;
 
-	while (tmp != filebuffer->next) {
-	    filebuffer = filebuffer->next;
+	while (tmp != openfile->next) {
+	    openfile = openfile->next;
 
 	    /* Save the current file buffer if it's been modified. */
-	    if (filebuffer->flags & MODIFIED) {
+	    if (openfile->flags & MODIFIED) {
 		/* Set fileage and filebot to match the current file
 		 * buffer, and then write it to disk. */
-		fileage = filebuffer->fileage;
-		filebot = filebuffer->filebot;
-		die_save_file(filebuffer->filename);
+		fileage = openfile->fileage;
+		filebot = openfile->filebot;
+		die_save_file(openfile->filename);
 	    }
 	}
     }
@@ -2544,7 +2544,7 @@ void do_spell(void)
     }
 
 #ifdef ENABLE_MULTIBUFFER
     /* Update the current filebuffer entry before spell-checking, in
      * case any problems occur. */
     add_open_file(TRUE);
 #endif
@@ -4667,7 +4667,7 @@ int main(int argc, char **argv)
 	new_file();
 	UNSET(VIEW_MODE);
 
 	/* Add this new entry to the filebuffer structure if we have
 	 * multibuffer support, or to the main filestruct if we
 	 * don't. */
 	load_file();
@@ -2544,7 +2544,7 @@ void do_spell(void)
 
 #ifdef ENABLE_MULTIBUFFER
-    /* Update the current filebuffer entry before spell-checking, in
+    /* Update the current openfile entry before spell-checking, in
      * case any problems occur. */
     add_open_file(TRUE);
@@ -4667,7 +4667,7 @@ int main(int argc, char **argv)
 	UNSET(VIEW_MODE);
 
-	/* Add this new entry to the filebuffer structure if we have
+	/* Add this new entry to the openfile structure if we have
 	 * multibuffer support, or to the main filestruct if we
 	 * don't. */